@@ -1,11 +1,6 @@
-use std::convert::Infallible;
-use std::fmt::Formatter;
-use std::marker::PhantomData;
-use std::mem;
-use std::ops::FromResidual;
+use std::{convert::Infallible, fmt::Formatter, marker::PhantomData, mem, ops::FromResidual};
 
-pub use protobuf::{CodedOutputStream, Message, ProtobufEnum};
-pub use protobuf::well_known_types::Any;
+pub use protobuf::{well_known_types::Any, CodedOutputStream, Message, ProtobufEnum};
 
 use crate::abi::*;
 
@@ -48,9 +43,10 @@ pub const CODE_EXPORTS: RetCode = -2;
 pub const CODE_WASI: RetCode = -3;
 pub const CODE_COMPILE: RetCode = -4;
 pub const CODE_INSTANTIATION: RetCode = -5;
-pub const CODE_PROTO: RetCode = -6;
-pub const CODE_NONE: RetCode = -7;
-pub const CODE_MEM: RetCode = -8;
+pub const CODE_RUNTIME: RetCode = -6;
+pub const CODE_PROTO: RetCode = -7;
+pub const CODE_NONE: RetCode = -8;
+pub const CODE_MEM: RetCode = -9;
 
 impl std::fmt::Display for CodeMsg {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
@@ -60,11 +56,7 @@ impl std::fmt::Display for CodeMsg {
 
 impl From<anyhow::Error> for CodeMsg {
     fn from(e: anyhow::Error) -> Self {
-        if e.is::<CodeMsg>() {
-            e.downcast().unwrap()
-        } else {
-            CodeMsg::new(CODE_UNKNOWN, e)
-        }
+        if e.is::<CodeMsg>() { e.downcast().unwrap() } else { CodeMsg::new(CODE_UNKNOWN, e) }
     }
 }
 
@@ -91,12 +83,15 @@ impl<R: Message> From<OutRets> for Result<R> {
         if out_rets.get_code() != 0 {
             return CodeMsg::result(out_rets.get_code(), out_rets.get_msg());
         }
-        out_rets.get_data()
-                .unpack::<R>()?
-            .map_or_else(
-                || CodeMsg::result(CODE_PROTO, "protobuf: the message type does not match the out_rets"),
-                |data| Ok(data),
-            )
+        out_rets.get_data().unpack::<R>()?.map_or_else(
+            || {
+                CodeMsg::result(
+                    CODE_PROTO,
+                    "protobuf: the message type does not match the out_rets",
+                )
+            },
+            |data| Ok(data),
+        )
     }
 }
 
@@ -108,21 +103,18 @@ impl InArgs {
         Ok(args)
     }
     pub fn get_args<R: Message>(&self) -> Result<R> {
-        self.get_data()
-            .unpack::<R>()?
-            .map_or_else(
-                || CodeMsg::result(CODE_PROTO, "protobuf: the message type does not match the in_args"),
-                |data| Ok(data),
-            )
+        self.get_data().unpack::<R>()?.map_or_else(
+            || CodeMsg::result(CODE_PROTO, "protobuf: the message type does not match the in_args"),
+            |data| Ok(data),
+        )
     }
 }
 
 pub fn unpack_any<R: Message>(data: &Any) -> Result<R> {
-    data.unpack::<R>()?
-        .map_or_else(
-            || CodeMsg::result(CODE_PROTO, "protobuf: the message type does not match the data"),
-            |r| Ok(r),
-        )
+    data.unpack::<R>()?.map_or_else(
+        || CodeMsg::result(CODE_PROTO, "protobuf: the message type does not match the data"),
+        |r| Ok(r),
+    )
 }
 
 pub fn pack_any<R: Message>(mut data: R) -> Result<Any> {
@@ -170,7 +162,7 @@ impl<R: Message> From<Result<R>> for OutRets {
                 }
                 res
             }
-            Err(e) => { e.into() }
+            Err(e) => e.into(),
         }
     }
 }
@@ -185,7 +177,9 @@ impl FromResidual<Result<Infallible>> for OutRets {
     fn from_residual(residual: Result<Infallible>) -> Self {
         match residual {
             Err(e) => e.into(),
-            _ => { unreachable!() }
+            _ => {
+                unreachable!()
+            }
         }
     }
 }
@@ -217,3 +211,10 @@ impl From<wasmer_wasi::WasiError> for CodeMsg {
         CodeMsg::new(CODE_WASI, v)
     }
 }
+
+#[cfg(not(target_family = "wasm"))]
+impl From<wasmer::RuntimeError> for CodeMsg {
+    fn from(v: wasmer::RuntimeError) -> Self {
+        CodeMsg::new(CODE_RUNTIME, format!("{:?}", v))
+    }
+}
